#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Edouard.Thiel@univ-amu.fr - 29/12/2013
#
# This script watches dbus events to detect fn brightness keys,
# so as to control the brightness of a monitor HP Dreamcolor2.
#
# The program must be run by the user at login; a good place is in
# gnome-session-properties.
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.

import glib
import dbus
from dbus.mainloop.glib import DBusGMainLoop
import os

def set_brightness (percent):
    if percent<0 : percent = 0
    elif percent>=100 : percent = 100
    os.system("/usr/local/dreamcolor2/dc2-set-brightness.sh --set-per %d" % percent)

def notifications (bus, message):
    if message.get_member() != "Notify": return
    args = message.get_args_list()
    dic = args[6]
    if dic['x-canonical-private-synchronous'] == "brightness": 
        set_brightness (dic['value'])


if __name__ == "__main__": 

    # Notify the current brightness to dbus
    os.system("/usr/local/dreamcolor2/dc2-set-brightness.sh --send-dbus")

    # Now watch for incoming events
    DBusGMainLoop(set_as_default=True)

    bus = dbus.SessionBus()
    bus.add_match_string_non_blocking("eavesdrop=true, interface='org.freedesktop.Notifications'")
    bus.add_message_filter(notifications)

    mainloop = glib.MainLoop()
    mainloop.run()

